# -*- coding: utf-8 -*-

import logging
import werkzeug

from odoo.addons.saas_worker.util import from_role, email_on_exception
from odoo.addons.saas_worker.compat import route, http, request
from odoo.addons.saas_worker.const import SAAS_BASE_URL

_logger = logging.getLogger(__name__)


def email_notify(template_ref, user_id, db, state):
    template = request.env.ref(template_ref)

    Users = request.env['res.users']
    to = Users.sudo().browse(user_id).partner_id.email
    context = {
        'email_to': to,
        'db_name': '{0}.{1}'.format(db.db_name, SAAS_BASE_URL),
        'db_url': db.url,
        'state': state,
    }
    template.sudo().with_context(context).send_mail(0)

class DumpController(http.Controller):
    @from_role('dbex')
    @email_on_exception(allowed_exceptions=(werkzeug.exceptions.HTTPException,))
    @route('/odoo-enterprise/dump-notify', auth='none', csrf=False)
    def dump_notify(self, **kw):
        Database = request.env['openerp.enterprise.database']
        template_ref = 'openerp_enterprise.dump_done'
        db = Database.sudo().search([('db_uuid', '=', kw.get('db_uuid'))])
        email_notify(template_ref, int(kw.get('user_id')), db, 'done')
        return

class RestoreController(http.Controller):

    @from_role('trial', 'bak')
    @email_on_exception(allowed_exceptions=(werkzeug.exceptions.HTTPException,))
    @route('/odoo-enterprise/restore-notify', auth='none', csrf=False, readonly=False)
    def notify(self, **kw):
        Database = request.env['openerp.enterprise.database']
        state = kw.get('state')
        if state == 'done':
            template_ref = 'openerp_enterprise.restore_done'
        else:
            template_ref = 'openerp_enterprise.restore_failed'

        db = Database.sudo().search([('db_uuid', '=', kw.get('db_uuid'))])
        email_notify(template_ref, int(kw.get('user_id')), db, state)
        return ''
